@@ -196,6 +196,17 @@ class UUID(Column):
         if not self.re_uuid.match(val):
             raise ValidationError("{} is not a valid uuid".format(value))
         return _UUID(val)
+    
+class TimeUUID(UUID):
+    """
+    UUID containing timestamp
+    """
+    
+    db_type = 'timeuuid'
+    
+    def __init__(self, **kwargs):
+        kwargs.setdefault('default', lambda: uuid1())
+        super(TimeUUID, self).__init__(**kwargs)
 
 class Boolean(Column):
     db_type = 'boolean'
